4.9. umbra.components.addons.traceUi.views — Umbra 1.0.4 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.4 documentation »
- 4. Api »

# 4.9. umbra.components.addons.traceUi.views

views.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  This module defines the `umbra.components.factory.traceUi.traceUi.TraceUi` Component Interface class View.

Others:

## 4.9.1. Module Attributes

`umbra.components.addons.traceUi.views.` `LOGGER`

## 4.9.2. Classes

class `umbra.components.addons.traceUi.views.` `Modules_QTreeView`(parent, model=None, readOnly=False, message=None)

  Bases: `umbra.ui.views.Abstract_QTreeView`

  This class is used to display modules.

  Parameters: | parent – Object parent. ( QObject ) model – Model. ( QObject ) readOnly – View is read only. ( Boolean ) message – View default message when Model is empty. ( String )

  `treeViewIndentation`

    This method is the property for self.__treeViewIndentation attribute.

    Returns: | self.__treeViewIndentation. ( Integer )

  `setModel`(model)

    This method reimplements the umbra.ui.views.Abstract_QTreeView.setModel method.

    Parameters: | model – Model to set. ( QObject )

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.4 documentation »
- 4. Api »